==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/nl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Gedeeld met anderen",
    "Shared with you" : "Met je gedeeld",
    "Shared by link" : "Gedeeld via een link",
    "Nothing shared with you yet" : "Nog niets met je gedeeld",
    "Files and folders others share with you will show up here" : "Bestanden en mappen die anderen met je delen, worden hier getoond",
    "Nothing shared yet" : "Nog niets gedeeld",
    "Files and folders you share will show up here" : "Bestanden en mappen die je deelt, worden hier getoond",
    "No shared links" : "Geen gedeelde links",
    "Files and folders you share by link will show up here" : "Bestanden en mappen die je via links deelt, worden hier getoond",
    "You can upload into this folder" : "Je kunt uploaden naar deze map",
    "No compatible server found at {remote}" : "Geen geschikte server gevonden op {remote}",
    "Invalid server URL" : "Ongeldig server URL",
    "Failed to add the public link to your Nextcloud" : "Kon de openbare link niet aan je Nextcloud toevoegen",
    "Share" : "Deel",
    "No expiration date set" : "Geen vervaldatum ingesteld",
    "Shared by" : "Gedeeld door",
    "Sharing" : "Delen",
    "File shares" : "File shares",
    "Downloaded via public link" : "Gedownload via een openbare link",
    "Downloaded by {email}" : "Gedownload via {email}",
    "{file} downloaded via public link" : "{file} gedownload via openbare link",
    "{email} downloaded {file}" : "{email} downloadde {file}",
    "Shared with group {group}" : "Deelde met groep {group}",
    "Removed share for group {group}" : "Share van de groep {group} verwijderd",
    "{actor} shared with group {group}" : "{actor} deelde met groep {group}",
    "{actor} removed share for group {group}" : "{actor} verwijderde de share voor groep {group}",
    "You shared {file} with group {group}" : "Je deelde {file} met groep {group}",
    "You removed group {group} from {file}" : "Je verwijderde groep  {group} van {file}",
    "{actor} shared {file} with group {group}" : "{actor} heeft het bestand {file} met groep {group} gedeeld",
    "{actor} removed group {group} from {file}" : "{actor} verwijderde groep {group} van {file}",
    "Shared as public link" : "Gedeeld als een openbare link",
    "Removed public link" : "Openbare link verwijderd",
    "Public link expired" : "Openbare link is verlopen",
    "{actor} shared as public link" : "{actor} deelde als een openbare link",
    "{actor} removed public link" : "{actor} verwijderde openbare link",
    "Public link of {actor} expired" : "Openbare link van {actor} is verlopen",
    "You shared {file} as public link" : "Je deelde {file} als openbare link",
    "You removed public link for {file}" : "Je verwijderde de openbare link voor {file}",
    "Public link expired for {file}" : "Openbare link voor {file} is verlopen",
    "{actor} shared {file} as public link" : "{actor} deelde {file} als openbare link",
    "{actor} removed public link for {file}" : "{actor} verwijderde openbare link voor {file}",
    "Public link of {actor} for {file} expired" : "Openbare link van {actor} voor {file} is verlopen",
    "{user} accepted the remote share" : "{user} accepteerde externe share",
    "{user} declined the remote share" : "{user} weigerde externe share",
    "You received a new remote share {file} from {user}" : "Je ontving een nieuwe externe share voor {file} van {user}",
    "{user} accepted the remote share of {file}" : "{user} accepteerde externe gedeelde folder van {file}",
    "{user} declined the remote share of {file}" : "{user} weigerde de externe gedeelde folder van {file}",
    "{user} unshared {file} from you" : "{user} is gestopt het bestand {file} met je te delen",
    "Shared with {user}" : "Gedeeld met {user}",
    "Removed share for {user}" : "Verwijderde gedeelde folder voor {user}",
    "{actor} shared with {user}" : "{actor} deelde met {user}",
    "{actor} removed share for {user}" : "{actor} verwijderde de gedeelde folder voor {user}",
    "Shared by {actor}" : "Gedeeld door {actor}",
    "{actor} removed share" : "{actor} verwijderde de gedeelde folder",
    "You shared {file} with {user}" : "Je deelde {file} met {user}",
    "You removed {user} from {file}" : "Je verwijderde {user} van {file}",
    "{actor} shared {file} with {user}" : "{actor} deelde {file} met {user}",
    "{actor} removed {user} from {file}" : "{actor} verwijderde {user} van {file}",
    "{actor} shared {file} with you" : "{actor} heeft {file} met je gedeeld",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Een bestand of map gedeeld via mail of publieke link werd <strong>gedownload</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Een bestand of map werd gedeeld vanaf <strong>een andere server</strong>",
    "A file or folder has been <strong>shared</strong>" : "Een bestand of map is <strong>gedeeld</strong>",
    "Wrong share ID, share doesn't exist" : "Onjuist deel-ID, de gedeelde folder bestaat niet",
    "could not delete share" : "Kan gedeelde folder niet verwijderen",
    "Could not delete share" : "Kan gedeelde folder niet verwijderen",
    "Please specify a file or folder path" : "Geef een bestand of pad van een map op",
    "Wrong path, file/folder doesn't exist" : "Onjuist pad, bestand/map bestaat niet",
    "Could not create share" : "Kan gedeelde folder niet aanmaken",
    "invalid permissions" : "Ongeldige rechten",
    "Please specify a valid user" : "Geef een geldige gebruiker op",
    "Group sharing is disabled by the administrator" : "Delen voor groepen is uitgeschakeld door de beheerder",
    "Please specify a valid group" : "Geef een geldige groep op",
    "Public link sharing is disabled by the administrator" : "Delen van openbare links is uitgeschakeld door de beheerder",
    "Public upload disabled by the administrator" : "Publieke upload uitgeschakeld door de systeembeheerder",
    "Public upload is only possible for publicly shared folders" : "Publieke upload is alleen mogelijk voor publiek gedeelde mappen",
    "Invalid date, date format must be YYYY-MM-DD" : "Ongeldige datum, datumnotatie moet in de vorm YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delen van %s mislukte omdat de backend het delen van type %s niet ondersteunt",
    "You cannot share to a Circle if the app is not enabled" : "Je kunt niets met een Kring delen als de app niet is ingeschakeld.",
    "Please specify a valid circle" : "Geef een geldige kring op",
    "Unknown share type" : "Onbekend type gedeelde folder",
    "Not a directory" : "Geen directory",
    "Could not lock path" : "Kan pad niet blokkeren",
    "Wrong or no update parameter given" : "Verkeerde of geen update parameter opgegeven",
    "Can't change permissions for public share links" : "Kan rechten voor openbaar gedeelde links niet wijzigen",
    "Cannot increase permissions" : "Kan de rechten niet verruimen",
    "shared by %s" : "Gedeeld door %s",
    "Download" : "Downloaden",
    "Direct link" : "Directe link",
    "Add to your Nextcloud" : "Toevoegen aan je Nextcloud",
    "Share API is disabled" : "Delen API is uitgeschakeld",
    "File sharing" : "Bestand delen",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Name" : "Naam",
    "Share time" : "Deel tijd",
    "Expiration date" : "Vervaldatm",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, deze link lijkt niet meer in gebruik te zijn.",
    "Reasons might be:" : "Redenen kunnen zijn:",
    "the item was removed" : "bestand was verwijderd",
    "the link expired" : "de link is verlopen",
    "sharing is disabled" : "delen is uitgeschakeld",
    "For more info, please ask the person who sent this link." : "Voor meer informatie, neem contact op met de persoon die u deze link heeft gestuurd.",
    "Download %s" : "Download %s",
    "Upload files to %s" : "Upload bestanden naar %s",
    "Select or drop files" : "Selecteer bestanden of sleep ze naar dit venster",
    "Uploading files…" : "Uploaden bestanden...",
    "Uploaded files:" : "Geüploade bestanden",
    "{actor} removed you from {file}" : "{actor} heeft je van {file} verwijderd",
    "%s is publicly shared" : "%s is openbaar gedeeld",
    "This share is password-protected" : "Deze gedeelde folder is met een wachtwoord beveiligd",
    "The password is wrong. Try again." : "Wachtwoord ongeldig. Probeer het nogmaals.",
    "Password" : "Wachtwoord"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/nl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Gedeeld met anderen",
    "Shared with you" : "Met je gedeeld",
    "Shared by link" : "Gedeeld via een link",
    "Deleted shares" : "Verwijderde shares",
    "Shares" : "Shares",
    "Nothing shared with you yet" : "Nog niets met je gedeeld",
    "Files and folders others share with you will show up here" : "Bestanden en mappen die anderen met je delen, worden hier getoond",
    "Nothing shared yet" : "Nog niets gedeeld",
    "Files and folders you share will show up here" : "Bestanden en mappen die je deelt, worden hier getoond",
    "No shared links" : "Geen gedeelde links",
    "Files and folders you share by link will show up here" : "Bestanden en mappen die je via links deelt, worden hier getoond",
    "No deleted shares" : "Geen verwijderde shares",
    "Shares you deleted will show up here" : "Shares die je verwijderde, worden hier getoond",
    "No shares" : "Geen shares",
    "Move or copy" : "Verplaatsen of kopiëren",
    "Download" : "Downloaden",
    "You can upload into this folder" : "Je kunt uploaden naar deze map",
    "No compatible server found at {remote}" : "Geen geschikte server gevonden op {remote}",
    "Invalid server URL" : "Ongeldig server URL",
    "Failed to add the public link to your Nextcloud" : "Kon de openbare link niet aan je Nextcloud toevoegen",
    "Share" : "Deel",
    "No expiration date set" : "Geen vervaldatum ingesteld",
    "Shared by" : "Gedeeld door",
    "Sharing" : "Delen",
    "File shares" : "File shares",
    "Downloaded via public link" : "Gedownload via een openbare link",
    "Downloaded by {email}" : "Gedownload via {email}",
    "{file} downloaded via public link" : "{file} gedownload via openbare link",
    "{email} downloaded {file}" : "{email} downloadde {file}",
    "Shared with group {group}" : "Deelde met groep {group}",
    "Removed share for group {group}" : "Share van de groep {group} verwijderd",
    "{actor} shared with group {group}" : "{actor} deelde met groep {group}",
    "{actor} removed share for group {group}" : "{actor} verwijderde de share voor groep {group}",
    "You shared {file} with group {group}" : "Je deelde {file} met groep {group}",
    "You removed group {group} from {file}" : "Je verwijderde groep  {group} van {file}",
    "{actor} shared {file} with group {group}" : "{actor} heeft het bestand {file} met groep {group} gedeeld",
    "{actor} removed group {group} from {file}" : "{actor} verwijderde groep {group} van {file}",
    "Shared as public link" : "Gedeeld als een openbare link",
    "Removed public link" : "Openbare link verwijderd",
    "Public link expired" : "Openbare link is verlopen",
    "{actor} shared as public link" : "{actor} deelde als een openbare link",
    "{actor} removed public link" : "{actor} verwijderde openbare link",
    "Public link of {actor} expired" : "Openbare link van {actor} is verlopen",
    "You shared {file} as public link" : "Je deelde {file} als openbare link",
    "You removed public link for {file}" : "Je verwijderde de openbare link voor {file}",
    "Public link expired for {file}" : "Openbare link voor {file} is verlopen",
    "{actor} shared {file} as public link" : "{actor} deelde {file} als openbare link",
    "{actor} removed public link for {file}" : "{actor} verwijderde openbare link voor {file}",
    "Public link of {actor} for {file} expired" : "Openbare link van {actor} voor {file} is verlopen",
    "{user} accepted the remote share" : "{user} accepteerde externe share",
    "{user} declined the remote share" : "{user} weigerde externe share",
    "You received a new remote share {file} from {user}" : "Je ontving een nieuwe externe share voor {file} van {user}",
    "{user} accepted the remote share of {file}" : "{user} accepteerde externe gedeelde folder van {file}",
    "{user} declined the remote share of {file}" : "{user} weigerde de externe gedeelde folder van {file}",
    "{user} unshared {file} from you" : "{user} is gestopt het bestand {file} met je te delen",
    "Shared with {user}" : "Gedeeld met {user}",
    "Removed share for {user}" : "Verwijderde gedeelde folder voor {user}",
    "{actor} shared with {user}" : "{actor} deelde met {user}",
    "{actor} removed share for {user}" : "{actor} verwijderde de gedeelde folder voor {user}",
    "Shared by {actor}" : "Gedeeld door {actor}",
    "{actor} removed share" : "{actor} verwijderde de gedeelde folder",
    "You shared {file} with {user}" : "Je deelde {file} met {user}",
    "You removed {user} from {file}" : "Je verwijderde {user} van {file}",
    "{actor} shared {file} with {user}" : "{actor} deelde {file} met {user}",
    "{actor} removed {user} from {file}" : "{actor} verwijderde {user} van {file}",
    "{actor} shared {file} with you" : "{actor} heeft {file} met je gedeeld",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Een bestand of map gedeeld via mail of publieke link werd <strong>gedownload</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Een bestand of map werd gedeeld vanaf <strong>een andere server</strong>",
    "A file or folder has been <strong>shared</strong>" : "Een bestand of map is <strong>gedeeld</strong>",
    "Wrong share ID, share doesn't exist" : "Onjuist deel-ID, de gedeelde folder bestaat niet",
    "could not delete share" : "Kan gedeelde folder niet verwijderen",
    "Could not delete share" : "Kan gedeelde folder niet verwijderen",
    "Please specify a file or folder path" : "Geef een bestand of pad van een map op",
    "Wrong path, file/folder doesn't exist" : "Onjuist pad, bestand/map bestaat niet",
    "Could not create share" : "Kan gedeelde folder niet aanmaken",
    "invalid permissions" : "Ongeldige rechten",
    "Please specify a valid user" : "Geef een geldige gebruiker op",
    "Group sharing is disabled by the administrator" : "Delen voor groepen is uitgeschakeld door de beheerder",
    "Please specify a valid group" : "Geef een geldige groep op",
    "Public link sharing is disabled by the administrator" : "Delen van openbare links is uitgeschakeld door de beheerder",
    "Public upload disabled by the administrator" : "Publieke upload uitgeschakeld door de systeembeheerder",
    "Public upload is only possible for publicly shared folders" : "Publieke upload is alleen mogelijk voor publiek gedeelde mappen",
    "Invalid date, date format must be YYYY-MM-DD" : "Ongeldige datum, datumnotatie moet in de vorm YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delen van %s mislukte omdat de backend het delen van type %s niet ondersteunt",
    "You cannot share to a Circle if the app is not enabled" : "Je kunt niets met een Kring delen als de app niet is ingeschakeld.",
    "Please specify a valid circle" : "Geef een geldige kring op",
    "Unknown share type" : "Onbekend type gedeelde folder",
    "Not a directory" : "Geen directory",
    "Could not lock path" : "Kan pad niet blokkeren",
    "Wrong or no update parameter given" : "Verkeerde of geen update parameter opgegeven",
    "Can't change permissions for public share links" : "Kan rechten voor openbaar gedeelde links niet wijzigen",
    "Cannot increase permissions" : "Kan de rechten niet verruimen",
    "shared by %s" : "Gedeeld door %s",
    "Direct link" : "Directe link",
    "Add to your Nextcloud" : "Toevoegen aan je Nextcloud",
    "Share API is disabled" : "Delen API is uitgeschakeld",
    "File sharing" : "Bestand delen",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Name" : "Naam",
    "Share time" : "Deel tijd",
    "Expiration date" : "Vervaldatm",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, deze link lijkt niet meer in gebruik te zijn.",
    "Reasons might be:" : "Redenen kunnen zijn:",
    "the item was removed" : "bestand was verwijderd",
    "the link expired" : "de link is verlopen",
    "sharing is disabled" : "delen is uitgeschakeld",
    "For more info, please ask the person who sent this link." : "Voor meer informatie, neem contact op met de persoon die u deze link heeft gestuurd.",
    "Download %s" : "Download %s",
    "Upload files to %s" : "Upload bestanden naar %s",
    "Select or drop files" : "Selecteer bestanden of sleep ze naar dit venster",
    "Uploading files…" : "Uploaden bestanden...",
    "Uploaded files:" : "Geüploade bestanden",
    "{actor} removed you from {file}" : "{actor} heeft je van {file} verwijderd",
    "%s is publicly shared" : "%s is openbaar gedeeld",
    "This share is password-protected" : "Deze gedeelde folder is met een wachtwoord beveiligd",
    "The password is wrong. Try again." : "Wachtwoord ongeldig. Probeer het nogmaals.",
    "Password" : "Wachtwoord"
},
"nplurals=2; plural=(n != 1);");
